@@ -1,21 +1,24 @@
 /* A demonstration of using HTTP basic authentication with XML-RPC.
 **
 ** In general, you shouldn't write XML-RPC servers which require basic
-** authenticaion. (Few XML-RPC clients support this, and it's not part of
+** authenticaion. (Few XML-RPC clients are capable of it, and it's not part of
 ** any standard.) Instead, you should pass any authentication information
 ** as a regular XML-RPC parameter (or look into using SSL).
 **
 ** But certain XML-RPC servers, including Zope, rely heavily on HTTP
 ** basic authentication. Here's how to talk to them. */
 
+#include <stdlib.h>
 #include <stdio.h>
 
-#include <xmlrpc.h>
-#include <xmlrpc_client.h>
+#include <xmlrpc-c/base.h>
+#include <xmlrpc-c/client.h>
+
+#include "config.h"  /* information about this build environment */
 
 #define NAME       "XML-RPC C Auth Client"
-#define VERSION    "0.1"
-#define SERVER_URL "http://xmlrpc-c.sourceforge.net/api/sample.php"
+#define VERSION    "1.0"
+#define SERVER_URL "http://localhost:8080/RPC2"
 
 static void die_if_fault_occurred (xmlrpc_env *env)
 {
@@ -26,13 +29,20 @@ static void die_if_fault_occurred (xmlrpc_env *env)
     }
 }
 
-int main (int argc, char** argv)
-{
+int 
+main(int           const argc, 
+     const char ** const argv ATTR_UNUSED) {
+
     xmlrpc_env env;
-    xmlrpc_server_info *server;
-    xmlrpc_value *result;    
-    char *user, *password;
+    xmlrpc_server_info * server;
+    xmlrpc_value * result;    
+    xmlrpc_int sum;
     
+    if (argc-1 > 0) {
+        fprintf(stderr, "There are no arguments.  You specified %d", argc-1);
+        exit(1);
+    }
+
     /* Start up our XML-RPC client library. */
     xmlrpc_client_init(XMLRPC_CLIENT_NO_FLAGS, NAME, VERSION);
     xmlrpc_env_init(&env);
@@ -45,21 +55,19 @@ int main (int argc, char** argv)
     xmlrpc_server_info_set_basic_auth(&env, server, "jrandom", "secret");
     die_if_fault_occurred(&env);
 
-    /* Ask the server to show us all our authentication information. */
-    result = xmlrpc_client_call_server(&env, server, "debug.authInfo", "()");
+    result = 
+        xmlrpc_client_call_server(
+            &env, server, "sample.add", "(ii)", 
+            (xmlrpc_int32) 5, (xmlrpc_int32) 7);
     die_if_fault_occurred(&env);
 
     /* Dispose of our server object. */
     xmlrpc_server_info_free(server);
     
     /* Get the authentication information and print it out. */
-    xmlrpc_parse_value(&env, result, "{s:s,s:s,*}",
-		       "user", &user,
-		       "password", &password);
+    xmlrpc_read_int(&env, result, &sum);
     die_if_fault_occurred(&env);
-    printf("You sent the following HTTP authentication information:\n");
-    printf("  User:     %s\n", user);
-    printf("  Password: %s\n", password);
+    printf("The sum is %d\n", sum);
     
     /* Dispose of our result value. */
     xmlrpc_DECREF(result);
